@@ -31,7 +31,6 @@
 #include <scrollkeeper.h>
 
 static char **av;
-static int verbose = 0;
 static char config_omf_dir[PATHLEN];
 
 static void add_element(char ***elem_tab, int *elem_num, char *elem)
@@ -106,14 +105,14 @@ bn_compare (const void *elem1, const void *elem2)
 static void
 usage (char **argv)
 {
-    printf(_("Usage: %s [-v] [-p <SCROLLKEEPER_DB_DIR>] [-o <OMF_DIR>]\n"),
+    printf(_("Usage: %s [-v] [-q] [-p <SCROLLKEEPER_DB_DIR>] [-o <OMF_DIR>]\n"),
 	    *argv);
 }
 
 static int parse_omf_dir(char *path, char **name_tab, int name_num, 
 				char ***install_tab, int *install_num,
 			        char ***uninstall_tab, int *uninstall_num,
-				char **dirs)
+				char **dirs, char outputprefs)
 {
     DIR *dir;
     struct dirent *dir_ent;
@@ -144,7 +143,7 @@ static int parse_omf_dir(char *path, char **name_tab, int name_num,
 	{
 	    parse_omf_dir(fullname, name_tab, name_num,
 			  install_tab, install_num,
-			  uninstall_tab, uninstall_num, dirs);
+			  uninstall_tab, uninstall_num, dirs, outputprefs);
 	    free (fullname);
 	    continue;
 	}
@@ -218,8 +217,7 @@ static int parse_omf_dir(char *path, char **name_tab, int name_num,
 
 	if (i != *install_num)
 	{
-	    sk_warning (verbose, _("%s: warning: %s overrides %s\n"), *av,
-		     	(*install_tab)[i], fullname);
+            sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "(parse_omf_dir)",_("%s: warning: %s overrides %s\n"), *av, (*install_tab)[i], fullname);
 	}
 	else
 	{
@@ -356,6 +354,7 @@ int main(int argc, char **argv)
     char scrollkeeper_data_dir[PATHLEN];
     char **upgrade_tab = NULL;
     char *s, **cpp;
+    char outputprefs=0;
 
     av = argv;
     
@@ -366,7 +365,7 @@ int main(int argc, char **argv)
     scrollkeeper_dir[0] = '\0';
     omf_dir[0] = '\0';
     
-    while ((i = getopt (argc, argv, "p:o:v")) != -1)
+    while ((i = getopt (argc, argv, "p:o:vq")) != -1)
     {
 	switch (i)
 	{
@@ -379,7 +378,11 @@ int main(int argc, char **argv)
 	    break;
 
 	case 'v':
-	    verbose = 1;
+	    outputprefs = outputprefs | SKOUT_STD_VERBOSE | SKOUT_LOG_VERBOSE; 
+	    break;
+
+	case 'q':
+	    outputprefs = outputprefs | SKOUT_STD_QUIET;
 	    break;
 
 	default:
@@ -439,8 +442,7 @@ int main(int argc, char **argv)
         fid = fopen(scrollkeeper_docs, "r");
 	if (!fid)
 	{
-	    sk_warning(verbose, "%s: %s: %s\n", *av, scrollkeeper_docs,
-		     strerror (errno));
+	    sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "scrollkeeper-update", "%s: %s: %s\n", *av, scrollkeeper_docs, strerror (errno));
 	    exit (EXIT_FAILURE);
 	}
 	
@@ -491,18 +493,18 @@ int main(int argc, char **argv)
     {
 	if (stat (*cpp, &buf) != 0)
 	{
-	   sk_warning (verbose, "%s: %s: %s\n", *av, *cpp, strerror (errno));
+	   sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "scrollkeeper-update", "%s: %s: %s\n", *av, *cpp, strerror (errno));
 	   continue;
 	}
 
 	if (! S_ISDIR (buf.st_mode))
 	{
-	   sk_warning (verbose, _("%s: %s: is not a directory\n"), *av, *cpp);
+	   sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "scrollkeeper-update", _("%s: %s: is not a directory\n"), *av, *cpp);
 	   continue;
 	}
 	
 	parse_omf_dir(*cpp, name_tab, line_num, &install_tab, &install_num,
-		      &uninstall_tab, &uninstall_num, omf_dirs);
+		      &uninstall_tab, &uninstall_num, omf_dirs, outputprefs);
     }
            
     for(i = 0; i < line_num; i++)
@@ -513,21 +515,21 @@ int main(int argc, char **argv)
         
     for(i = 0; i < install_num; i++)
     {
-	sk_warning(verbose, _("scrollkeeper-update: Registering %s\n"), install_tab[i]);
-	install(install_tab[i], scrollkeeper_dir, scrollkeeper_data_dir, verbose);
+	sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "scrollkeeper-update",_("Registering %s\n"), install_tab[i]);
+	install(install_tab[i], scrollkeeper_dir, scrollkeeper_data_dir, outputprefs);
     }
     
     for(i = 0; i < upgrade_num; i++)
     {
-	sk_warning(verbose, _("scrollkeeper-update: Updating %s\n"), upgrade_tab[i]);
-	uninstall(upgrade_tab[i], scrollkeeper_dir, verbose);
-	install(upgrade_tab[i], scrollkeeper_dir, scrollkeeper_data_dir, verbose);
+	sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "scrollkeeper-update",_("Updating %s\n"), upgrade_tab[i]);
+	uninstall(upgrade_tab[i], scrollkeeper_dir, outputprefs);
+	install(upgrade_tab[i], scrollkeeper_dir, scrollkeeper_data_dir, outputprefs);
     }
     
     for(i = 0; i < uninstall_num; i++)
     {
-	sk_warning(verbose, _("scrollkeeper-update: Unregistering %s\n"), uninstall_tab[i]);
-    	uninstall(uninstall_tab[i], scrollkeeper_dir, verbose);
+	sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "scrollkeeper-update",_("Unregistering %s\n"), uninstall_tab[i]);
+    	uninstall(uninstall_tab[i], scrollkeeper_dir, outputprefs);
     }
     
     for(i = 0; i < install_num; i++)
