@@ -38,8 +38,6 @@
 /*extern char *strtok_r(char *, const char *, char **);*/
 #endif
 
-static int verbose = 0;
-
 static int get_unique_doc_id(char *);
 static void add_doc_to_scrollkeeper_docs(char *, char *, char *, int, char *);
 static void add_doc_to_content_list(xmlNodePtr, char *, char **, char *, char *,
@@ -142,7 +140,7 @@ static xmlNodePtr create_toc_tree(char *docpath)
     return toc_tree;
 }
 
-int install(char *omf_name, char *scrollkeeper_dir, char *data_dir, int v)
+int install(char *omf_name, char *scrollkeeper_dir, char *data_dir, char outputprefs)
 {    
     xmlDocPtr omf_doc;
     xmlNodePtr node, s_node, c_node;
@@ -155,12 +153,10 @@ int install(char *omf_name, char *scrollkeeper_dir, char *data_dir, int v)
     char **stylesheets=NULL, **output_files=NULL, *toc_name;
     char *toc_stylesheet_name, *index_name, *index_stylesheet_name, *uid;
          
-    verbose = v;
-    
     omf_doc = xmlParseFile(omf_name);
     if (omf_doc == NULL)
     {
-        sk_warning(verbose, _("wrong omf file %s\n"), omf_name);
+        sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "(install)", _("wrong omf file %s\n"), omf_name);
         return 0;
     }
 		      	          
@@ -190,14 +186,14 @@ int install(char *omf_name, char *scrollkeeper_dir, char *data_dir, int v)
 	    cl_doc = xmlParseFile(cl_filename);
     	    if (cl_doc == NULL)
     	    {
-        	sk_warning(verbose, _("wrong content list file %s\n"), cl_filename);
+        	sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "(install)", _("wrong content list file %s\n"), cl_filename);
         	continue;
     	    }
 	    
 	    cl_ext_doc = xmlParseFile(cl_ext_filename);
     	    if (cl_ext_doc == NULL)
     	    {
-        	sk_warning(verbose, _("wrong extended content list file %s\n"), cl_ext_filename);
+        	sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "(install)", _("wrong extended content list file %s\n"), cl_ext_filename);
         	continue;
     	    }
 
@@ -250,7 +246,7 @@ int install(char *omf_name, char *scrollkeeper_dir, char *data_dir, int v)
                 output_files[1] = index_name;
 
 		apply_stylesheets(ptr, format+5, 2, 
-					stylesheets, output_files);
+					stylesheets, output_files, outputprefs);
 		
 		free(toc_name);
 		free(toc_stylesheet_name);
